@@ -1,4 +1,4 @@
-from tf_lambda.layers import LambdaLayer
+from tf_lambda.layers.lambda_layer import LambdaLayer
 
 class LambdaConv(Layer):
 
